@@ -17,13 +17,9 @@ if(!isGeneric("convpow"))
 ## -- absolute continuous distribution -- 
 ##########################################################
 
-##implentation of Algorithm 3.4. of 
-# Kohl, M., Ruckdeschel, P., Stabla, T. (2005): 
-#   General purpose convolution algorithm for distributions 
-#   in S4-Classes by means of FFT.
-# Technical report, Feb. 2005. Also available in
-# http://www.uni-bayreuth.de/departments/math/org/mathe7/
-#       /RUCKDESCHEL/pubs/comp.pdf
+##implentation of Algorithm 3.4. of
+#P. Ruckdeschel, M. Kohl (2014): General Purpose Convolution Algorithm for
+# Distributions in S4 Classes by Means of FFT. J. Statist. Softw. 59(4), 1-25.
 
 
 setMethod("convpow",
@@ -40,8 +36,8 @@ setMethod("convpow",
                              q(D1)(getdistrOption("TruncQuantile"))
                            ) 
             upper <- ifelse((q(D1)(1) < Inf), q(D1)(1), 
-                             q(D1)(getdistrOption("TruncQuantile", 
-                                   lower.tail = FALSE))
+                             q(D1)(getdistrOption("TruncQuantile"),
+                                   lower.tail = FALSE)
                            )
 
     ##STEP 2
